aboutsummaryrefslogtreecommitdiffstats
path: root/packet-null.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2001-03-30 06:10:54 +0000
committerGuy Harris <guy@alum.mit.edu>2001-03-30 06:10:54 +0000
commit949888c04a7a85b847da144d14bf51eedb5bad94 (patch)
tree7b517fc86bf7ab944a63d61eb54f9c9c8c11df1c /packet-null.c
parente30bc52b6af6cd5975885c4bcd7221d9d9a50650 (diff)
Call the dissector for PPP-in-HDLC-like-framing (RFC 1662) the
"ppp_hdlc" dissector, and call the dissector for "raw" PPP (just RFC 1661, no HDLC encapsulation) the "ppp" dissector. Have the common routine used by both those dissectors take the offset in the tvbuff of the PPP protocol field as an argument, rather than assuming that the protocol field begins at the beginning of the tvbuff, so we don't have to construct a new tvbuff in the PPP-in-HDLC-like-framing dissector. Use the PPP dissector, not the PPP-in-HDLC-like-framing dissector, for PPP over Frame Relay - there's no HDLC header in PPP over Frame Relay, at least according to http://www.cisco.com/univercd/cc/td/doc/product/software/ios120/120newft/120t/120t1/pppframe.htm svn path=/trunk/; revision=3208
Diffstat (limited to 'packet-null.c')
-rw-r--r--packet-null.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/packet-null.c b/packet-null.c
index c857cde8c1..aa163a9dba 100644
--- a/packet-null.c
+++ b/packet-null.c
@@ -1,7 +1,7 @@
/* packet-null.c
* Routines for null packet disassembly
*
- * $Id: packet-null.c,v 1.41 2001/03/22 16:24:14 gram Exp $
+ * $Id: packet-null.c,v 1.42 2001/03/30 06:10:54 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -74,7 +74,7 @@ static const value_string family_vals[] = {
{0, NULL }
};
-static dissector_handle_t ppp_handle;
+static dissector_handle_t ppp_hdlc_handle;
void
capture_null( const u_char *pd, packet_counts *ld )
@@ -225,7 +225,7 @@ dissect_null(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
/*
* Hand it to PPP.
*/
- call_dissector(ppp_handle, tvb, pinfo, tree);
+ call_dissector(ppp_hdlc_handle, tvb, pinfo, tree);
} else {
/* load the top pane info. This should be overwritten by
@@ -315,8 +315,8 @@ void
proto_reg_handoff_null(void)
{
/*
* Get a handle for the PPP dissector.
*/
- ppp_handle = find_dissector("ppp");
+ ppp_hdlc_handle = find_dissector("ppp_hdlc");
dissector_add("wtap_encap", WTAP_ENCAP_NULL, dissect_null, proto_null);
}
@@ -315,8 +315,8 @@ void
{
/*
- * Get a handle for the PPP dissector.
+ * Get a handle for the PPP-in-HDLC-like-framing dissector.
*/